@@ -1,3 +1,4 @@
+from PyQt5.QtGui import QColor, qGray
 from PyQt5.QtWidgets import QWidget, QMainWindow, QDialog, QAbstractButton
 from pyqt_svg_button import SvgButton
 
@@ -14,9 +15,9 @@ class QtSassTheme:
         cur_dir = os.path.dirname(__file__)
         ico_filename = os.path.join(cur_dir, 'ico/_icons.scss')
         icon_path = cur_dir.replace(os.path.sep, posixpath.sep)
-        self.__setIcoInDetail(ico_filename, icon_path)
+        self.__setIcoPath(ico_filename, icon_path)
 
-    def __setIcoInDetail(self, ico_filename: str, icon_path: str):
+    def __setIcoPath(self, ico_filename: str, icon_path: str):
         import_abspath_str = f'$icopath: \'{icon_path}/\';'
         with open(ico_filename, 'r+') as f:
             fdata = f.read()
@@ -36,7 +37,17 @@ class QtSassTheme:
                     f.seek(0, 0)
                     f.write(import_abspath_str + '\n' + fdata)
 
-    def __setVarInDetail(self, var_filename: str, background_darker=False):
+    def __setCustomThemeColor(self, var_filename: str, theme_color: str):
+        with open(var_filename, 'r+') as f:
+            fdata = f.read()
+            m = re.search(r'\$bgcolor:(.+\n)', fdata)
+            if m:
+                custom_theme_code = f'$bgcolor: {theme_color};\n'
+                f.truncate(0)
+                f.seek(0, 0)
+                f.write(custom_theme_code + ''.join(fdata.splitlines(True)[1:]))
+
+    def __setBackgroundPolicy(self, var_filename: str, background_darker=False):
         if background_darker:
              with open(var_filename, 'r+') as f:
                 fdata = f.read()
@@ -63,11 +74,39 @@ class QtSassTheme:
         return css
 
     def getThemeFiles(self, theme: str = 'dark_gray', background_darker=False, output_path=os.getcwd()):
+        theme_lst = ['dark_gray', 'dark_blue', 'light_gray', 'light_blue']
         cur_dir = os.path.dirname(__file__)
-        theme_prefix = theme.split('_')[0]
-        ico_dirname = os.path.join(cur_dir, os.path.join('ico', theme_prefix))
+        official_theme_flag = theme in theme_lst
+        if official_theme_flag:
+            theme_prefix = theme.split('_')[0]
+            ico_dirname = os.path.join(cur_dir, os.path.join('ico', theme_prefix))
+            var_dirname = os.path.join(cur_dir, os.path.join(os.path.join('var', theme_prefix), theme))
+
+        # check whether theme value is 6-digit hex color
+        else:
+            m = re.match(r'#[a-fA-F0-9]{6}', theme)
+            if m:
+                theme_color = m.group(0)
+                theme_color = QColor(theme_color)
+
+                # 'if it is, check 6-digit hex color is lighter than usual or darker')
+                r, g, b = theme_color.red(), theme_color.green(), theme_color.blue()
+                theme_lightness = ''
+                if qGray(r, g, b) > 255 // 2:
+                    theme_lightness = 'light'
+                else:
+                    theme_lightness = 'dark'
+
+                # get the ico_dirname
+                ico_dirname = os.path.join(cur_dir, os.path.join('ico', theme_lightness))
+
+                # get the dark_gray/light_gray theme
+                var_dirname = os.path.join(cur_dir, os.path.join(os.path.join('var', theme_lightness),
+                                                                 theme_lightness+'_gray'))
+            else:
+                raise Exception('Invalid theme')
+
         sass_dirname = os.path.join(cur_dir, 'sass')
-        var_dirname = os.path.join(cur_dir, os.path.join(os.path.join('var', theme_prefix), theme))
         os.chdir(output_path)
         output_dirname = 'res'
         if os.path.exists(output_dirname):
@@ -86,10 +125,14 @@ class QtSassTheme:
         shutil.copytree(var_dirname, 'var')
 
         ico_filename = 'ico/_icons.scss'
-        self.__setIcoInDetail(ico_filename, output_dirname)
+        self.__setIcoPath(ico_filename, output_dirname)
 
         var_filename = 'var/_variables.scss'
-        self.__setVarInDetail(var_filename, background_darker)
+        if official_theme_flag:
+            pass
+        else:
+            self.__setCustomThemeColor(var_filename, theme)
+        self.__setBackgroundPolicy(var_filename, background_darker)
 
     def setThemeFiles(self, main_window: QWidget, input_path='res', exclude_type_lst: list = []):
         if os.path.basename(os.getcwd()) != input_path:
